# GCD Simple Minimum LoD Barplot R Script v.2

# Last updated: 10/2/2013
# Created by: Sara Bangen (sara.bangen@gmail.com)

# This script was written for GCD users who have a basic working knowledge
# of R and desire greater user control over DoD distribution plots produced 
# from the GCD output.  The user will need to specify the function arguments
# which are detailed below under "Args:".

# Plots are produced using the ggplot2 package.

# Outputs: *.pdf of unthresholded elevation change distribution plots.
#
# Args:
#   data.in:     Filepath to raw.csv file.
#   vol.Title:   Title of volume plot.  Needs to have " around text (e.g. "2012-2011 Volumetric Change")
#   area.Title:  Title of area plot.  Needs to have " around text (e.g. "2012-2011 Areal Change")
#   plot.width:  Plot width in inches.
#   plot.height: Plot height in inches.
#   plot.out:    Output *.pdf filepath.
#   plot.type:   "area" - script will only ouput areal change plot
#                "volume" - script will only ouput volumetric change plot
#                "both" - script will ouput both areal and volumetric change plots


# User defined arguments

data.in     = read.csv("C:\\etal\\Private\\sara.bangen\\Scripts\\R\\test\\raw.csv", header=T)
vol.Title   = "RAW VOLUMETRIC CHANGE"
area.Title  = "RAW AREAL CHANGE"
plot.width  = c (8)
plot.height = c (8)
plot.out    = "C:\\etal\\Private\\sara.bangen\\Scripts\\R\\test\\raw5.pdf"
plot.type   = "volume"

# Check if required packages are installed
# If not, install the packages

if (!'ggplot2' %in% installed.packages()) install.packages('ggplot2')
if (!'reshape2' %in% installed.packages()) install.packages('reshape2')
if (!'grid' %in% installed.packages()) install.packages('grid')

# gcdPlot Function

gcdPlot = function(data.in, plot.width, plot.height, plot.type, plot.out){

  # Call on packages needed for this script
  require (reshape2)
  require (ggplot2)
  require (grid)
  
  # Shorten column names
  colnames(data.in)     = c("LowerElevRange.m", "UpperElevRange.m", "TotalArea.m2", "TotalVol.m3", "CellCount")
  
  # Create separate columns for erosion and deposition using conditional ifelse statement
  data.in$AreaEros.m2   = ifelse(data.in$LowerElevRange.m<0,data.in$TotalArea.m2,0)
  data.in$AreaDep.m2    = ifelse(data.in$LowerElevRange.m>=0,data.in$TotalArea.m2,0)
  data.in$VolumeEros.m3 = ifelse(data.in$LowerElevRange.m<0,data.in$TotalVol.m3,0)
  data.in$VolumeDep.m3  = ifelse(data.in$LowerElevRange.m>=0,data.in$TotalVol.m3,0)
  
  # Create new data.vol and data.area dataframes copying only columns needed for plots
  # Melt new dataframes for plotting purposes
  data.vol              = data.in[, c("LowerElevRange.m", "VolumeEros.m3","VolumeDep.m3")]
  m.data.vol            = melt(data.vol, id.vars = 1)
  data.area             = data.in[, c("LowerElevRange.m", "AreaEros.m2","AreaDep.m2")]
  m.data.area           = melt(data.area, id.vars = 1)
  
  # Create areal change barplot and assign to object 'area.Plot'
  # Plot elevation range ~ areal change value and fill based on varible (i.e. eros, dep)
    area.Plot = ggplot(m.data.area, aes(LowerElevRange.m, value, fill=variable)) +
    geom_bar(stat            ="identity", size = .05) +
    
    # Set bar fill colors
    scale_fill_manual(values = c("#C00000", "#1B3F8B")) +
    
    # Define x and y axis labels and plot title
    xlab("Elevation Change (m)") + 
    ylab(expression(paste("Area"," ",(m^2)))) +
    ggtitle(area.Title) +
    
    # Set theme to black and white.  Other option in ggplot is theme_grey()
    theme_bw() + 
    
    # Set y limits
    coord_cartesian(ylim = range(pretty(c(0, data.in$TotalArea.m2)))) + 
    
    # Define x and y axis and plot label font size and color
    theme(axis.title.x      = element_text(size=12), axis.text.x = element_text(colour = "#404040", size=10)) +
    theme(axis.title.y      = element_text(size=12), axis.text.y = element_text(colour = "#404040",size=10)) +
    theme(plot.title        = element_text(size=14)) +
  
    # Supress plot legend
    theme(legend.position   = "none") +
      
    # Set plot legned margins  
    theme(plot.margin       = unit(c(.25,.25,.25,.25), "lines")) 

  # Create volumetric change barplot and assign to object 'vol.Plot'
  # Plot elevation range ~ volumetric change value and fill based on varible (i.e. eros, dep)
    vol.Plot = ggplot(m.data.vol, aes(LowerElevRange.m, value, fill=variable)) +
    geom_bar(stat            ="identity", size = .05) +
    
    # Set bar fill colors
    scale_fill_manual(values = c("#C00000", "#1B3F8B")) +
    
    # Define x and y axis labels and plot title
    xlab("Elevation Change (m)") + 
    ylab(expression(paste("Volume"," ",(m^3)))) +
    ggtitle(vol.Title) +
    
    # Set theme to black and white.  Other option is theme_grey()
    theme_bw() + 
    
    # Set y limits
    coord_cartesian(ylim = range(pretty(c(0, data.in$TotalVol.m3)))) +
    
    # Define x and y axis and plot label font size and color
    theme(axis.title.x      = element_text(size=12), axis.text.x = element_text(colour = "#404040", size=10)) +
    theme(axis.title.y      = element_text(size=12), axis.text.y = element_text(colour = "#404040",size=10)) +
    theme(plot.title        = element_text(size=14)) +
  
    # Supress plot legend
    theme(legend.position   = "none") +
    
    # Set plot legned margins  
    theme(plot.margin       = unit(c(.25,.25,.25,.25), "lines")) 
  
  # Output plot based on ifelse statement and using PDF graphics device
  # If plot.type is set to volume, only the volumetric change plot will be output
  # Else if plot.type is set to area, only the areal change plot will be output
  # Else both the volumetric and areal plots will be output
  if(plot.type == "volume"){
    pdf(plot.out, paper="special", width=plot.width, height=plot.height, useDingbats=FALSE)
    print(vol.Plot)
    dev.off()
    } else if
      (plot.type == "area"){
      pdf(plot.out, paper = "special", width=plot.width, height=plot.height, useDingbats=FALSE)
      print(area.Plot)
      dev.off() 
    } else{
      pdf(plot.out, paper = "special", width=plot.width, height=plot.height, useDingbats=FALSE)
      vp.setup <- function(x,y){
      grid.newpage()
      pushViewport(viewport(layout = grid.layout(x,y)))}
      vp.layout <- function(x,y){
      viewport(layout.pos.row=x, layout.pos.col=y)}
      vp.setup(2,1)
      print(area.Plot, vp = vp.layout(1, 1))
      print(vol.Plot, vp = vp.layout(2, 1))
      dev.off()
    }
}


gcdPlot(data.in, plot.width, plot.height, plot.type, plot.out)




