# GCD Thresholded Barplot R Script v.2

# Last updated: 10/2/2013
# Created by: Sara Bangen (sara.bangen@gmail.com)

# This script was written for GCD users who have a basic working knowledge
# of R and desire greater user control over DoD distribution plots produced 
# from the GCD output.  The user will need to specify the function arguments
# which are detailed below under below.

# Plots are produced using the ggplot2 package.

# Outputs: *.pdf of thresholded elevation change distribution plots.
#
# Args:
#   data.raw:    Filepath to raw.csv file.
#   data.thresh: Filepath to thresholded.csv file.
#   vol.Title:   Title of volume plot.  Needs to have " around text (e.g. "2012-2011 Volumetric Change")
#   area.Title:  Title of area plot.  Needs to have " around text (e.g. "2012-2011 Areal Change")
#   plot.width:  Plot width in inches.
#   plot.height: Plot height in inches.
#   plot.out:    Output *.pdf filepath.
#   plot.type:   "area" - script will only ouput areal change plot
#                "volume" - script will only ouput volumetric change plot
#                "both" - script will ouput both areal and volumetric change plots


# User defined arguments

data.raw    = read.csv("C:\\etal\\Private\\sara.bangen\\Scripts\\R\\GCD_Barplot\\raw.csv", header=T)
data.thresh = read.csv("C:\\etal\\Private\\sara.bangen\\Scripts\\R\\GCD_Barplot\\thresholded.csv", header=T)
vol.Title   = "THRESHOLDED VOLUMETRIC CHANGE"
area.Title  = "THRESHOLDED AREAL CHANGE"
plot.width  = c (6)
plot.height = c (8)
plot.out    = "C:\\etal\\Private\\sara.bangen\\Scripts\\R\\GCD_Barplot\\thresh_plots.pdf"
plot.type   = "both"

# Check if required packages are installed
# If not, install the packages

if (!'ggplot2' %in% installed.packages()) install.packages('ggplot2')
if (!'reshape2' %in% installed.packages()) install.packages('reshape2')
if (!'grid' %in% installed.packages()) install.packages('grid')

# gcdPlot Function

gcdPlot = function(data.in, plot.width, plot.height, plot.type, plot.out){

  # Call on packages needed for this script
  require (reshape2)
  require (ggplot2)
  require (grid)
  
  # Shorten column names
  colnames(data.thresh) = c("LowerElevRange.m", "UpperElevRange.m", "ThreshTotalArea.m2", "ThreshTotalVol.m3", "CellCount")
  
  # Add raw total area and raw total volume to data.dodhtresh data frame 
  data.thresh$RawTotalArea.m2 = data.raw[, c("Total.Area..m2.")]
  data.thresh$RawTotalVol.m3  = data.raw[, c("Total.Volume..m3.")]
  
  # Calculate area and volume of changes due to DEM noise
  data.thresh$NoiseArea.m2 = data.thresh$RawTotalArea.m2 - data.thresh$ThreshTotalArea.m2
  data.thresh$NoiseVol.m3  = data.thresh$RawTotalVol.m3 - data.thresh$ThreshTotalVol.m3
  
  # Create separate columns for erosion and deposition using conditional ifelse statement
  data.thresh$ThreshAreaEros.m2   = ifelse(data.thresh$LowerElevRange.m<0,data.thresh$ThreshTotalArea.m2,0)
  data.thresh$ThreshAreaDep.m2    = ifelse(data.thresh$LowerElevRange.m>=0,data.thresh$ThreshTotalArea.m2,0)
  data.thresh$ThreshVolumeEros.m3 = ifelse(data.thresh$LowerElevRange.m<0,data.thresh$ThreshTotalVol.m3,0)
  data.thresh$ThreshVolumeDep.m3  = ifelse(data.thresh$LowerElevRange.m>=0,data.thresh$ThreshTotalVol.m3,0)
  
  # Create new data.vol and data.area dataframes copying only columns needed for plots
  # Melt new dataframes for plotting purposes
  data.threshvol  = data.thresh[, c("LowerElevRange.m", "ThreshVolumeEros.m3","ThreshVolumeDep.m3","NoiseVol.m3")]
  m.data.threshvol = melt(data.threshvol, id.vars=1)
  data.thresharea = data.thresh[, c("LowerElevRange.m", "ThreshAreaEros.m2","ThreshAreaDep.m2","NoiseArea.m2")]
  m.data.thresharea = melt(data.thresharea, id.vars=1)
  
  # Create areal change barplot and assign to object 'area.Plot'
  # Plot elevation range ~ areal change value and fill based on varible (i.e. eros, dep)
    area.Plot = ggplot(m.data.thresharea, aes(LowerElevRange.m, value, fill=variable)) +
    geom_bar(stat            ="identity", size = .05) +
    
    # Set bar fill colors
    scale_fill_manual(values = c("#C00000", "#1B3F8B", "grey")) +
    
    # Define x and y axis labels and plot title
    xlab("Elevation Change (m)") + 
    ylab(expression(paste("Area"," ",(m^2)))) +
    ggtitle(area.Title) +
    
    # Set theme to black and white.  Other option in ggplot is theme_grey()
    theme_bw() + 
    
    # Set y limits
    coord_cartesian(ylim = range(pretty(c(0, data.thresh$RawTotalArea.m2)))) + 
    
    # Define x and y axis and plot label font size and color
    theme(axis.title.x      = element_text(size=12), axis.text.x = element_text(colour = "#404040", size=10)) +
    theme(axis.title.y      = element_text(size=12), axis.text.y = element_text(colour = "#404040",size=10)) +
    theme(plot.title        = element_text(size=14)) +
  
    # Supress plot legend
    theme(legend.position   = "none") +
      
    # Set plot legned margins  
    theme(plot.margin       = unit(c(.25,.25,.25,.25), "lines")) 

  # Create volumetric change barplot and assign to object 'vol.Plot'
  # Plot elevation range ~ volumetric change value and fill based on varible (i.e. eros, dep)
    vol.Plot = ggplot(m.data.threshvol, aes(LowerElevRange.m, value, fill=variable)) +
    geom_bar(stat            ="identity", size = .05) +
    
    # Set bar fill colors
    scale_fill_manual(values = c("#C00000", "#1B3F8B", "grey")) +
    
    # Define x and y axis labels and plot title
    xlab("Elevation Change (m)") + 
    ylab(expression(paste("Volume"," ",(m^3)))) +
    ggtitle(vol.Title) +
    
    # Set theme to black and white.  Other option is theme_grey()
    theme_bw() + 
    
    # Set y limits
    coord_cartesian(ylim = range(pretty(c(0, data.thresh$RawTotalVol.m3)))) +
    
    # Define x and y axis and plot label font size and color
    theme(axis.title.x      = element_text(size=12), axis.text.x = element_text(colour = "#404040", size=10)) +
    theme(axis.title.y      = element_text(size=12), axis.text.y = element_text(colour = "#404040",size=10)) +
    theme(plot.title        = element_text(size=14)) +
  
    # Supress plot legend
    theme(legend.position   = "none") +
    
    # Set plot legned margins  
    theme(plot.margin       = unit(c(.25,.25,.25,.25), "lines")) 
  
  # Output plot based on ifelse statement
  # If plot.type is set to volume, only the volumetric change plot will be output
  # Else if plot.type is set to area, only the areal change plot will be output
  # Else both the volumetric and areal plots will be output
  if(plot.type == "volume"){
    pdf(plot.out, paper="special", width=plot.width, height=plot.height, useDingbats=FALSE)
    print(vol.Plot)
    dev.off()
    } else if
      (plot.type == "area"){
      pdf(plot.out, paper = "special", width=plot.width, height=plot.height, useDingbats=FALSE)
      print(area.Plot)
      dev.off() 
    } else{
      pdf(plot.out, paper = "special", width=plot.width, height=plot.height, useDingbats=FALSE)
      vp.setup <- function(x,y){
      grid.newpage()
      pushViewport(viewport(layout = grid.layout(x,y)))}
      vp.layout <- function(x,y){
      viewport(layout.pos.row=x, layout.pos.col=y)}
      vp.setup(2,1)
      print(area.Plot, vp = vp.layout(1, 1))
      print(vol.Plot, vp = vp.layout(2, 1))
      dev.off()
    }
}


gcdPlot(data.in, plot.width, plot.height, plot.type, plot.out)




